@@ -76,3 +76,8 @@ class CreateTransitRouterRequest(RpcRequest):
 
 	def set_TransitRouterDescription(self, TransitRouterDescription):  # String
 		self.add_query_param('TransitRouterDescription', TransitRouterDescription)
+	def get_SupportMulticast(self): # Boolean
+		return self.get_query_params().get('SupportMulticast')
+
+	def set_SupportMulticast(self, SupportMulticast):  # Boolean
+		self.add_query_param('SupportMulticast', SupportMulticast)
